Improve this doc

# Getting Started

We want you to have an easy time while starting to use Angular. We've put together the following steps on your path to becoming an Angular expert.

1. Read the conceptual overview.
   Understand Angular's vocabulary and how all the Angular components work together.
2. Do the AngularJS Tutorial.
   Walk end-to-end through building an application complete with tests on top of a node.js web server. Covers every major AngularJS feature and shows you how to set up your development environment.
3. Download or clone the Seed App project template.
   Gives you a starter app with a directory layout, test harness, and scripts to begin building your application.

# Further Steps

## Watch Videos

If you haven’t had a chance to watch the videos from the homepage, please check out:

- Introduction to AngularJS
- Creating Directives
- Communicating with Servers

And visit our YouTube channel for more AngularJS video presentations and tutorials.

## Subscribe

- Subscribe to the mailing list. Ask questions here!
- Follow us on Twitter
- Add us to your circles on Google+

## Read more

The AngularJS documentation includes the Developer Guide covering concepts and the API Reference for syntax and usage.